package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````GAP```````!``````````'"A````
M`````````$``.``(`$``%P`6``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````9`````````!D``````````0`````````!````
M!0```````````````````````````````````&R4````````;)0`````````
M`"````````$````&````,)P````````PG"```````#"<(```````<`0`````
M```X%0``````````(````````@````8```!8G````````%B<(```````6)P@
M``````!P`0```````'`!````````"`````````!0Y71D!````#R/````````
M/(\````````\CP```````,0`````````Q``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````PG````````#"<(```````,)P@``````#0`P``````
M`-`#`````````0`````````O;&EB+VQD+6UU<VPM>#@V7S8T+G-O+C$`````
M`````!$```!$````!`````@````@#```!4`$@B@`4`"0A@"`@B$`($D"!`FX
M@AA)N@0&"D0```!%````20```$T```!.````5````%4```!7`````````%L`
M````````7````%X```!?````8```````````````H^D9!&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;_+;TQWB1\8!
MN^.2?%7#/-+$N9Q`9Z_,9CCRBQS$B060B`=PTT-%U>PS8MOM5J2;EJ?=HVM_
MJ9R;X:<""@J*$%>CX/M)``````````````````````````````````````P`
M```2`````````````````````````,X!```2````````````````````````
M`'`!```2`````````````````````````!L````2````````````````````
M`````*T!```2`````````````````````````",````2````````````````
M`````````"H````2``````````````````````````$"```2````````````
M`````````````+D!```2`````````````````````````#,````@````````
M`````````````````$L````2`````````````````````````%$````2````
M`````````````````````%@````2`````````````````````````!`#```2
M``````````````````````````$#```2`````````````````````````(8"
M```2`````````````````````````%\````2````````````````````````
M`"<"```2`````````````````````````&8````2````````````````````
M`````+L"```2`````````````````````````&T````2````````````````
M`````````'4````@`````````````````````````(D````2````````````
M`````````````*0"```2`````````````````````````)$````2````````
M`````````````````)<````2`````````````````````````*`````@````
M`````````````````````/H"```2`````````````````````````+P````2
M`````````````````````````,$````2`````````````````````````,("
M```2`````````````````````````%0"```2````````````````````````
M`"`#```2`````````````````````````$8"```2````````````````````
M`````*0#```2`````````````````````````'@"```2````````````````
M`````````#8#```2`````````````````````````,@````2````````````
M`````````````"X#```2`````````````````````````'X!```2````````
M`````````````````-$````B`````````````````````````.`````@````
M`````````````````````/8````2`````````````````````````/("```2
M`````````````````````````&0"```2`````````````````````````/L`
M```2``````````````````````````$!```@````````````````````````
M`*\"```2`````````````````````````!L!```2````````````````````
M`````)X!```2`````````````````````````"`!```2````````````````
M`````````)0"```2`````````````````````````(T!```2````````````
M`````````````"8!```2`````````````````````````#<!```2````````
M`````````````````"("```2`````````````````````````)(````2````
M`````````````````````#,"```2`````````````````````````&T"```2
M`````````````````````````"<#```2`````````````````````````#T!
M```2`````````````````````````!@#```2````````````````````````
M`%$!```2`````````````````````````!T"```2````````````````````
M`````-P!```2`````````````````````````%@!```2````````````````
M`````````&D!```2`````````````````````````$@#```A`!0`L*`@````
M```(`````````$,#```2``D`R!H```````#6`0```````.X!```2``H`H$X`
M```````!`````````.8#```2``D`%$$```````#+"0```````%P$```2``D`
M*DX```````!1`````````,,#```2``D`?CL````````%`````````/4#```2
M``8`N!@````````!``````````D$```2``D`WTH```````!+`P```````$\$
M```2``D`@SL```````#``0```````%H#```0`!0`H*`@````````````````
M`-0#```2``D`)T````````#M`````````/,#```2``D`$#H````````M````
M`````/L#```2``D`P#\```````!(`````````,T"```1`!0`P*`@```````3
M`````````"D$```2``D`0ST````````;`````````&8#```0`!0`:+$@````
M`````````````(D#```2``D`M!P````````H`````````$D#```1`!0`L*`@
M```````(`````````#8$```2``D`7CT```````"B`````````!0````1`!0`
MH*`@```````(`````````$H#```A`!0`L*`@```````(`````````!\$```1
M`!,`F*`@```````(`````````%,#```0`!,`H*`@`````````````````%\#
M```0``D`GAP``````````````````!("```1`!0`N*`@```````$````````
M`$L#```A`!0`L*`@```````(`````````)(#```2``D`"$`````````?````
M`````*T#```2``D`@SH```````#[`````````/0!```1`!0`J*`@```````!
M`````````$($```2``D``#X```````#``0````````!L:6)P97)L+G-O`&]P
M96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I
M<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N
M;&EN:P!M96UM;W9E`%]*=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A
M=`!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S
M=')S='(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M
M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R
M96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S
M<&5C:69I8P!M96UC<'D`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F,N;75S;"UX.#9?-C0N<V\N,0!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T
M9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?
M;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T
M`%]E;F0`+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`7W-T87)T7V,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK
M=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A;G5P`+B>(```````"```
M``````"X&`````````"@(```````"```````````H"```````""@(```````
M"`````````#A3P```````"B@(```````"`````````#73P```````#"@(```
M````"`````````#D3P```````#B@(```````"`````````#:3P```````$"@
M(```````"`````````#?3P```````$B@(```````"`````````#Q3P``````
M`&"@(```````"`````````">3P```````&B@(```````"`````````"73P``
M`````'"@(```````"`````````#O4````````'B@(```````"`````````"T
M3P```````("@(```````"`````````#W4````````)B@(```````"```````
M``"*40```````."=(```````!@````$``````````````.B=(```````!@``
M``(``````````````/"=(```````!@````,``````````````/B=(```````
M!@````0```````````````">(```````!@````4```````````````B>(```
M````!@````8``````````````!">(```````!@````<``````````````!B>
M(```````!@````@``````````````"">(```````!@````D`````````````
M`"B>(```````!@````H``````````````#">(```````!@````L`````````
M`````#B>(```````!@````P``````````````$">(```````!@````T`````
M`````````$B>(```````!@````X``````````````%">(```````!@````\`
M`````````````%B>(```````!@```!```````````````&">(```````!@``
M`!$``````````````&B>(```````!@```!(``````````````'">(```````
M!@```!,``````````````'B>(```````!@```!0``````````````(">(```
M````!@```!4``````````````(B>(```````!@```!8``````````````)">
M(```````!@```!<``````````````)B>(```````!@```!@`````````````
M`*">(```````!@```!D``````````````*B>(```````!@```!H`````````
M`````+">(```````!@```!L``````````````,">(```````!@```!P`````
M`````````,B>(```````!@```!T``````````````-">(```````!@```!X`
M`````````````-B>(```````!@```!\``````````````.">(```````!@``
M`"```````````````.B>(```````!@```"$``````````````/">(```````
M!@```"(``````````````/B>(```````!@```",```````````````"?(```
M````!@```"0```````````````B?(```````!@```"4``````````````!"?
M(```````!@```"8``````````````!B?(```````!@```"<`````````````
M`""?(```````!@```"@``````````````"B?(```````!@```"D`````````
M`````#"?(```````!@```"H``````````````#B?(```````!@```"L`````
M`````````$"?(```````!@```"P``````````````$B?(```````!@```"T`
M`````````````%"?(```````!@```"X``````````````%B?(```````!@``
M`"\``````````````&"?(```````!@```#```````````````&B?(```````
M!@```#$``````````````'"?(```````!@```#(``````````````'B?(```
M````!@```#,``````````````("?(```````!@```#0``````````````(B?
M(```````!@```#4``````````````)"?(```````!@```#8`````````````
M`)B?(```````!@```#<``````````````*"?(```````!@```#@`````````
M`````*B?(```````!@```#D``````````````+"?(```````!@```#H`````
M`````````+B?(```````!@```#L``````````````,"?(```````!@```#P`
M`````````````,B?(```````!@```#T``````````````-"?(```````!@``
M`#X``````````````-B?(```````!@```#\``````````````."?(```````
M!@```$```````````````.B?(```````!@```$$``````````````/"?(```
M````!@```$(``````````````/B?(```````!@```$,``````````````*"@
M(```````!0```%<``````````````*B@(```````!0```&``````````````
M`+"@(```````!0```%4``````````````+B@(```````!0```%P`````````
M`````,"@(```````!0```%$``````````````%#H#04``.BX-0``6,,`````
M`````````/\U^H0@`/\E_(0@``\?0`#_)?J$(`!FD/\E^H0@`&:0_R7ZA"``
M9I#_)?J$(`!FD/\E^H0@`&:0_R7ZA"``9I#_)?J$(`!FD/\E^H0@`&:0_R7Z
MA"``9I#_)?J$(`!FD/\E^H0@`&:0_R7ZA"``9I#_)?J$(`!FD/\E^H0@`&:0
M_R7ZA"``9I#_)?J$(`!FD/\E^H0@`&:0_R7ZA"``9I#_)?J$(`!FD/\E^H0@
M`&:0_R7ZA"``9I#_)0*%(`!FD/\E`H4@`&:0_R4"A2``9I#_)0*%(`!FD/\E
M$H4@`&:0_R42A2``9I#_)1*%(`!FD/\E$H4@`&:0_R42A2``9I#_)1*%(`!F
MD/\E$H4@`&:0_R42A2``9I#_)1*%(`!FD/\E$H4@`&:0_R42A2``9I#_)1*%
M(`!FD/\E$H4@`&:0_R42A2``9I#_)1*%(`!FD/\E$H4@`&:0_R42A2``9I#_
M)1*%(`!FD/\E$H4@`&:0_R4:A2``9I#_)1J%(`!FD/\E&H4@`&:0_R4:A2``
M9I#_)2J%(`!FD/\E*H4@`&:0_R4JA2``9I#_)2J%(`!FD/\E,H4@`&:0_R4R
MA2``9I#_)3*%(`!FD/\E,H4@`&:0_R4RA2``9I#_)3*%(`!FD/\E,H4@`&:0
M_R4RA2``9I#_)3*%(`!FD%-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-="00
M2(U4)`CH&?___TB+-;J$(`!(BSV+A"``2(GRZ$O^__^`/9R%(```=37HK?[_
M_TB%P$B)!4.6(`!U"K\!````Z/?^__](B<?H'____XL]@84@`.A4____QH"E
M"````(L];X4@`.A"____@(BB!````HL]784@`.@P____@(BB!````8M$)!R-
M>`5(N/________\?2&/_2#G'=A5(C34YA2``2(T]83,``#'`Z(O]__](P><#
M2(T=Y#4``.B;_O__2(M\)!!(B067E2``,<G'!9.5(``$````2(L72(E8"$B-
M';PU``!(B5@82(D02(L5OX0@`$B)4!"+5"0<2/_!.<I^$4R+!,^-<01(8_9,
MB43P^.OHC4H$2(L]794@`$B--3,>``"#P@-%,<!(8\E(QT3(^`````!(B<'H
M;/W__X7`B<-U#DB+/2^5(`#H^OW__XG#2(L](94@`.BD_?__2(T]\C(``#'`
MZ)<9``!(A<!U+DB#/?F4(```=1-(C3V*,@``Z'P9``!(B07DE"``2(L]W90@
M`$B%_W0%Z*4Q``!(BSW4E"``Z!?^___H6OS__TB#Q"")V%O#2#'M2(GG2(TU
MK7\@`$B#Y/#H`````$B#[`A(C5<(2(LW3(T%VC$``$B+#>N!(`!%,<E(C3WQ
M_?__Z!3]__](C3V]@R``2(T%O8,@`%5(*?A(B>5(@_@.=@](BP6R@2``2(7`
M=`-=_^!=PTB-/9&#(`!(C36*@R``N0(```!52"G^2,'^`TB)Y4B)\$B92/?Y
M2(7`=!)(B<9(BP4;@B``2(7`=`-=_^!=PX`]DH,@``!U>DB#/="!(```54B)
MY4%44W0,2(L]F((@`.BC_/__2(T%S'X@`$B-'<U^(`!(*<-)B<1(P?L#2/_+
M2(L%68,@`$@YPW802/_`2(D%2H,@`$'_%,3KY.@S____2(,]=X`@``!T#$B-
M/89R``#H:?O__UM!7%W&!1:#(``!PTB#/5V!(```54B)Y7032(TU((,@`$B-
M/5ER``#H+/S__TB-/5U^(`!(@S\`=`Y(BP6(@"``2(7`=`+_T%WI^_[__T%7
M059,C4\X055!5#'V55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B-3"0(
M08L$,4V+!#$/R$R)PHG`2,'J($B)!'%,B<!)P>@X2,'H*"4`_P``3`G`28G0
M2,'B"$G!X!B!X@``_P!%B<!,"<!("=!(B41Q"$B#Q@A(@_Y`=:U,C5EH3(U1
M0$R-21!,C8&`````,=))BP0323,$$DDS!!%(,P012(TT`$C!Z!\)\$F)!!!(
M@\((2('Z``(``'753(L/2(M?($R+1PA,BU<03(M?&$B+3"003(G.3(G(38G/
M2,'H&TC!Y@5-B<1("<9(BT0D"$R)PHGV2,'J`DG!Y!Y)"=1,B=))C8P+F7F"
M6DB-A`.9>8):18GD2<'G'DPQXD@!\$R)UDPARDPQWDPQTDPAQD@!T4PQWD@!
MQHGP2(G"2(G%2,'M&TC!X@5(">J)TD@!RDR)R4C!Z0)!B=9)"<](B<%,B?5%
MB?](]]%(P>T;3"'A3"'^2`G.2(M,)!A)C8P*F7F"6D@!SDR)\4C!X05(">E(
MB<5(P>@"2,'E'HG)2`'Q2`GHB<5,B?!!B<U(]]!((>I,B>Y,(?A(P>X;2`G"
M2(M$)"!)C80$F7F"6D@!PDR)Z$C!X`5("?!,B>Z)P$CWUD@!T$R)\DG![@)(
MP>(>2"'N08G$20G62(M4)"A%B?9,(?%("?%)C;07F7F"6DR)XDC!ZAM(`?%,
MB>9(P>8%2`G63(GJ2<'M`DC!XAZ)]DD)U4R)XD@!SD6)[4CWTD&)]TPA\DPA
MZ$R)^4@)T$B+5"0P2,'I&TB-E!69>8):2`'03(GZ2,'B!4@)RDR)^8G22/?1
M2`'"3(G@2,'@'DG![`),(>E)"<1(BT0D.(G518GD3"'F2`G.28V,!IEY@EI(
MB>A(P>@;2`'.2(GI2,'A!4@)P4R)^$G![P)(P>`>B<E)"<=(B>A(`?%%B?](
M]]!!B<Y,(>!,(?I,B?9("<)(BT0D0$C![AM)C80%F7F"6D@!PDR)\$C!X`5(
M"?!,B?:)P$CWUD@!T$B)ZDC![0)(P>(>3"'^08G%2`G52(M4)$B)[4@AZ4@)
M\4F-M!29>8):3(GJ2,'J&T@!\4R)[DC!Y@5("=9,B?*)]D@!SDC!XAY)P>X"
M20G63(GJ08GT18GV2/?23(GA2"'J3"'P2,'I&T@)T$B+5"1028V4%YEY@EI(
M`=!,B>)(P>(%2`G*3(GAB=)(]]%(`<),B>A)P>T"2,'@'DPA\4&)UTD)Q4B+
M1"1818GM3"'N2`G.2(V,!9EY@EI,B?A(P>@;2`'.3(GY2,'A!4@)P4R)X$G!
M[`)(P>`>B<E)"<1,B?A(`?%%B>1(]]")S4PAZ$PAXDB)[D@)PDB+1"1@2,'N
M&TF-A`:9>8):2`'"2(GH2,'@!4@)\$B)[HG`2/?62`'03(GZ2<'O`DC!XAY,
M(>9!B<9)"==(BU0D:$6)_TPA^4@)\4F-M!69>8):3(GR2,'J&T@!\4R)]DC!
MY@5("=9(B>I(P>T"2,'B'HGV2`G53(GR2`'.B>U(]])!B?5,(?I((>A,B>E(
M"=!(BU0D<$C!Z1M)C904F7F"6D@!T$R)ZDC!X@5("<I,B>F)TDCWT4@!PDR)
M\$G![@)(P>`>2"'I08G420G&2(M$)'A%B?9,(?9("<Y)C8P'F7F"6DR)X$C!
MZ!M(`<Y,B>%(P>$%2`G!3(GH2<'M`DC!X!Z)R4D)Q4R)X$@!\46)[4CWT$&)
MSTPA\$PAZDR)_D@)PDB+A"2`````2,'N&TB-A`69>8):2`'"3(GX2,'@!4@)
M\$R)_HG`2/?62`'03(GB2<'L`DC!XAY,(>Z)Q4D)U$B+E"2(````18GD3"'A
M2`GQ28VT%IEY@EI(B>I-B?Y(P>H;2<'O`D@!\4B)[DG!YAY(P>8%30GW2`G6
M2(GJ18G^2/?23"'PB?9,(>)(`<Y)B>]("=!(BY0DD````(GQ28V4%9EY@EI)
MB<U(`=!(B<I(P>(%2<'M&TG!YQY,">I(P>T"3`G]B=)!B>](`<)(B<U(BX0D
MF````$CWU4PA_DPA]4&)U4@)[DF-K`29>8):3(GH2,'H&T@![DR)[4C!Y05(
M"<5(B<A(P>D"2,'@'HGM2`G!3(GH2`'U2/?0B<Y!B>Q,(?A((?)("<)(BX0D
MH````$F-A`:9>8):38GF2<'N&T@!PDR)X$C!X`5,"?")P$@!T$R)ZDG![0)(
MP>(>08G&20G52(N4)*@```!,,>DQS4F-E!>AZ]EN2(U,%0!,B?),B?5(P>T;
M2,'B!4@)ZHG22`'*3(GA2<'L`DC!X1Z)U4P)X4V)[$6)[4DQS$P#K"2X````
M1#'@3(ND)+````!*C;0FH>O9;DF)[$G![!M(`?!(B>Y(P>8%3`GF38GT2<'N
M`DG!Y!Z)]DT)]$F)SD@!\$TQYHG&B<E$,?))B?9(`XPDP````$V-K!6AZ]EN
M2(GR2<'N&TC!X@5,"?*)TDV-=!4`2(GJ2,'M`DC!XAY(">I,B>5%B?5(,=5%
MB>0QZ$B-K`&AZ]EN3(GH3(GI2,'I&TC!X`5("<B)P$B-3`4`2(GU2,'N`DC!
MY1Y("?5,`Z0DR````$B)UD@Q[HG(B=)!,?9(B<9(`Y0DT````$C!Y@5/C:0T
MH>O9;DF)QDG![AM,"?:)]DV--#1,B>Y)P>T"2,'F'DP)[DF)[46)]$DQ]8GM
M2`.L)-@```!$,>E-B>5(C8P*H>O9;DR)XDG![1M(P>(%3`GJB=)(`<I(B<%(
MP>@"2,'A'D&)U4@)P4B)\(GV2#'(2`.T).````!!,<9,B>A.C;0UH>O9;DR)
M[4C!X`5(P>T;2`GHB<!)C2P&3(G@2<'L`DC!X!Y,">!)B<Q!B>Y),<2)R40Q
MXDR-I!:AZ]EN3(GR3(GV2,'B!4C![AM(`XPDZ````$@)\HG228TT%$R)ZDG!
M[0)(P>(>3`GJ28G%08GT23'5B<!(`X0D\````$0Q[4V)Y4B-K"FAZ]EN3(GA
M2<'M&TC!X05,">F)R4@!Z4R)]4G![@)(P>4>08G-3`GU28G6B=)),>Y(`Y0D
M^````$0Q]DV)[DB-M#"AZ]EN3(GH2<'N&TC!X`5,"?")P$@!\$R)YDG![`)(
MP>8>08G&3`GF28GLB>U),?1$,>%-B?1(C8P*H>O9;DR)\DG![!M(P>(%3`GB
MB=)(`<I,B>E(`ZPD``$``$G![0)(P>$>08G43`GI28GUB?9),<U(`[0D"`$`
M`$0QZ$R-K`6AZ]EN3(G@3(GE2,'M&TC!X`5(">B)P$F-;`4`3(GP2<'N`DC!
MX!Y,"?!)B<Y!B>U),<:)R4@#C"00`0``1#'R3(VT%J'KV6Y,B>I,B>Y(P>X;
M2,'B!4@)\HG228TT%DR)XDG![`)(P>(>3`GB28G$08GV23'4B<!$,>5-B?1(
MC:PIH>O9;DR)\4G![!M(P>$%3`GAB<E(`>E,B>U)P>T"2,'E'D&)S$P)[4@#
MA"08`0``28G523'MB=)(`Y0D(`$``$0Q[DV)Y4G![1M(C;0PH>O9;DR)X$C!
MX`5,">B)P$@!\$R)]DG![@)(P>8>08G%3`GV28GNB>U),?9(`ZPD*`$``$0Q
M\4V)[DB-C`JAZ]EN3(GJ2<'N&TC!X@5,"?*)TD@!RDR)X4G![`)(P>$>08G6
M3`GA28GTB?9),<Q(`[0D,`$``$V)]T0QX$R-I`6AZ]EN3(GP3(GU2,'M&TC!
MX`5(">B)P$F-+`1,B>A)P>T"2,'@'DP)Z$F)S4&)[$DQQ8G)1#'J38GE2(VT
M%J'KV6Y,B>)(P>(%2<'M&T@#C"0X`0``3`GJ2<'N`DG!YQZ)TDT)]TV)YDR-
M+!9(B<9)P>P"3#'^2<'F'HG`1(GJ,?5(`X0D0`$``$B-M"FAZ]EN2(G12(G5
M2,'M&TC!X05-">9(">E,B?U%B?],,?6)R4$Q[4@!\8G.3HVD**'KV6Y)B=5(
MB?!(P>H"2(GU2<'E'DC![1M(P>`%20G53(GR2`GH3`GJB<!((=%,B?))C2P$
M3"'JN-R\&X]%B?8)T4B)PD@#E"1(`0``08GL3`'Z38GG2`'13(GB2,'B!4G!
M[QM,"?J)TD@!RDB)\4C![@)(P>$>08G72`GQ3(GN2`G.2"'U3(GN18GM2"'.
M"?5(B<9(`[0D4`$``$D!]DR)_DD![DR)_4C!Y@5(P>T;2`GNB?9)C2PV3(GF
M2<'L`DC!YAY,">9)B<Q!B>Y)"?1,(>))B<R)R4DA]$0)XDF)Q$P#I"18`0``
M30'L38GU3`'B38GT2<'E!4G![!M-">5%B>U.C20J3(GZ2<'O`DC!XAY,"?I)
MB?=%B>5)"==,(?U)B?>)]DDAUT0)_4F)QTP#O"1@`0``20'/3(GI3`']38GO
M2,'A!4G![QM,"?F)R4R-?`T`3(GQ2<'N`DC!X1Y,"?%)B=9$B?U)"<Y-(?1)
MB=:)TDDASD4)]$F)QDP#M"1H`0``20'V2(GN30'T28GN2,'F!4G![AM,"?:)
M]DV--#1-B>Q)P>T"2<'D'DT)[$F)S42)]DT)Y4TA[TF)S8G)32'E10GO28G%
M3`.L)'`!``!)`=5(B?)-`>])B?5(P>(%2<'M&TP)ZHG238TL%TB)ZDC![0)(
MP>(>2`G53(GB18GO2`GJ22'63(GB18GD2"'J00G62(G"2`.4)'@!``!(`=%,
MB?I,`?%-B?Y(P>(%2<'N&TP)\HG23(TT$4B)\4C![@)(P>$>2`G.2(GI1(GR
M2`GQ22'-2(GIB>U((?%!"<U(B<%(`XPD@`$``$D!S$B)T4T![$F)U4C!X05)
MP>T;3`GIB<E-C2P,3(GY2,'A'DG![P),"?E)B?=%B>Q)"<]-(?Y)B?>)]DDA
MST4)_DF)QTP#O"2(`0``20'O3(GE30'^38GG2,'E!4G![QM,"?V)[4V-/"Y(
MB=5(P>H"2,'E'D@)ZDB)S46)_D@)U4DA[4B)S8G)2"'500GM2(G%2`.L))`!
M``!(`>Y,B?5,`>Y-B?5(P>4%2<'M&TP)[8GM3(TL+DR)YDG![`)(P>8>20GT
M2(G61(GM3`GF22'W2(G6B=),(>9!"?=(B<9(`[0DF`$``$@!\4B)[DP!^4F)
M[TC!Y@5)P>\;3`G^B?9,C3PQ3(GV2<'N`DC!YAY,"?9-B>9$B?E)"?9-(?5-
MB>9%B>1)(?9%"?5)B<9,`[0DH`$``$D!UDB)RDT!]4F)SDC!X@5)P>X;3`GR
MB=)-C705`$B)ZDC![0)(P>(>2`G52(GR18GU2`GJ22'72(GRB?9((>I!"==(
MB<)(`Y0DJ`$``$D!U$R)ZDT!_$V)[TC!X@5)P>\;3`GZB=)-C3P428G,2<'D
M'DC!Z0),">%)B>Q$B?I)"<Q-(>9)B>R)[4DAS$4)YDF)Q$P#I"2P`0``3`'F
M28G43`'V28G62<'D!4G![AM-"?1%B>1.C30F3(GN2<'M`DC!YAY)"?5(B<Y%
MB?1,">Y)(?=(B<Z)R4PA[D$)]TB)QD@#M"2X`0``2`'U3(GF3`']38GG2,'F
M!4G![QM,"?Z)]DR-?#4`2(G62,'J`DC!YAY("=9,B>I$B?U("?))(=9,B>I%
MB>U((?)!"=9(B<)(`Y0DP`$``$@!RDB)Z4D!UDB)ZDC!X05(P>H;2`G1B<E)
MC10.3(GA2<'L`DC!X1Y)"<Q(B?%!B=9,">%)(<](B?&)]DPAX4$)STB)P4@#
MC"3(`0``20'-3(GQ30']38GW2,'A!4G![QM,"?F)R4V-?`T`28GM2,'M`DG!
MY1Y,">U-B>5$B?E)">U,(>I-B>5%B>1)(>U$">I)B<5,`ZPDT`$``$P![DF)
MS4@!UDB)RDG!Y05(P>H;20G518GM2HT4+DR)]DG![@)(P>8>20GV2(GN08G5
M3`GV22'W2(GN3"'V00GW2(G&2`.T)-@!``!(`X0DX`$``$D!]$R)[DT!_$V)
M[TC!Y@5)P>\;3`G^B?9-C3PT2(G.2,'I`DC!YAY("<Y,B?%%B?Q("?%((<I,
MB?%%B?9((?$)RHGI2`'!3(G@2`'*3(GA2,'H&TC!X05("<%,B>A)P>T"B<E(
MP>`>2`'1NM;!8LI,">A)B=5,`ZPDZ`$``(G-30'N28GUB?9),<5%,>])B>U-
M`?=)B>Y)P>4%2<'N&TT)]4V)YDG![`))P>8>18GM30GF28G43`.D)/`!``!-
M`?U%B>],`>9)B<2)P$TQ]$0QX4V)_$@!\4R)_DG![!M(P>8%3`GF28GL2,'M
M`DG!Y!Z)]DD)[$B)U4@#K"3X`0``2`'QB<Y(`>A,B?5%B?9,,>5!,>U(B?5)
M`<5(B?!(P>4%2,'H&T@)Q8GM3`'M38G]2<'E'DG![P*)Z$T)_4F)UTP#O"0`
M`@``30'^38GG18GD33'O1#'Y28G'3`'Q28G&2<'O&TG!Y@5-"?Y)B?=(P>X"
M2<'G'D6)]DD)]TB)UD@#M"0(`@``20'.1(GQ20'T3(GN18GM3#'^,?5(B<Y,
M`>5)B<Q(P>8%2<'L&TP)YHGV2`'N2(G%2,'H`DC!Y1Y!B?1("<5(B=!(`X0D
M$`(``$D!Q4R)^$6)_T@QZ$$QQDR)X$T![DV)Y4C!X`5)P>T;3`GHB<!,`?!)
MB<Y(P>D"2<'F'D&)Q4P)\4F)UDP#M"08`@``30'W28GNB>U),<Y$,?9-B>Y,
M`?Y-B>])P>X;2<'G!4T)]T6)_TD!]TR)YDG![`)(P>8>18G^20GT2(G62`.T
M)"`"``!(`?5(B<Z)R4PQYC'P3(GV2`'H3(GU2,'N&TC!Y05("?5,B>Y)P>T"
M2,'F'HGM3`GN28G53`.L)"@"``!(`<6)Z$P!Z4V)Y46)Y$DQ]44Q[TF)Q4D!
MSTB)P4G!Y05(P>D;20G-18GM30']38GW2<'N`DG!YQY$B>E-"?Y)B==,`[PD
M,`(``$T!_$F)]XGV33'W1#']28G/3`'E28G,2<'O&TG!Y`5-"?Q%B>1)`>Q(
MB<5(P>@"2,'E'D6)YT@)Z$B)U4@#K"0X`@``2`'N3(GU18GV2#'%03'M3(G]
M20'U3(G^2,'M&TC!Y@5(">Y(B<V)]DP![DC!Y1Y(P>D"2`G-2(G12`.,)$`"
M``!!B?5)`<Y(B<&)P$@QZ4$QS$R)Z4T!]$V)[DC!X05)P>X;3`GQB<E,`>%-
MB?Q)P>\"2<'D'D&)SDT)YTF)U$P#I"1(`@``3`'@28GLB>U-,?Q$,>9-B?1(
M`<9,B?!)P>P;2,'@!4P)X(G`2`'P3(GN2<'M`DC!YAY!B<1)"?5(B=9(`[0D
M4`(``$@!]4R)_D6)_TPQ[C'Q3(GF2`'I3(GE2,'E!4C![AM("?6)[4@!S4R)
M\4G![@)(P>$>B>Y)"<Y(B=%(`XPD6`(``$D!STR)Z46)[4PQ\3'(2(GQ3`'X
M28GW2,'I&TG!YP5)"<],B>%)P>P"2,'A'D6)_TP)X4F)U$P#I"1@`@``20''
M1(GX30'E38GT18GV23',1#'E28G$3`'M28G%2<'D!4G![1M-">Q)B?5(P>X"
M2<'E'D6)Y$D)]4B)UD@#M"1H`@``20'L1(GE20'V2(G.B<E,,>Y!,?=(B>Y-
M`?=)B>Y(P>8%2<'N&TP)]DF)QDC!Z`))P>8>B?9)"<9(B=!(`X0D<`(``$P!
M_D&)]T@!P4R)Z$6)[4PQ\$$QQ$R)^$D!S$R)^4C!Z!M(P>$%2`G!B<E,`>%)
MB>Q(P>T"2<'D'HG(3`GE28G43`.D)'@"``!-`>5-B?1),>Q$,>9)B<1)`?5(
MB<9)P>P;2,'F!4P)YDF)Q$$!]4R)_DC!YAY(`Y0D@`(``$C!Z`))P>0>2<'O
M`D4!Z$D)Q$2)\$P)_D4!XD$!\P'K2`'"2(GH3(E'"$@Q\$R)5Q!,B5\8,<%(
MB5\@2(T$"DR)ZDR)Z4C!X@5(P>D;2`G*`=!!`<%(BX0DB`(``&1(,P0E*```
M`$R)#W0%Z&KE__](@<28`@``6UU!7$%=05Y!7\-!5T%6055!5%53,>U(@^P(
M2(7_=&5,BS4T:R``2(GZ387V=%:*`H3`=`D\/70%2/_"Z_$I^DF)]TF)_4V)
M]$ACVDF++"1(A>UT,$B)VDR)[DB)[^C0X___A<!U&(!\'0`]=1%-*?1(C6P=
M`4G!_`-%B2?K!DF#Q`CKQUI(B>A;74%<05U!7D%?PTB#[!AD2(L$)2@```!(
MB40D"#'`2(UT)`3H6?___TB+5"0(9$@S%"4H````=`7HG.3__TB#Q!C#55-(
MB?M(@^P89$B+!"4H````2(E$)`@QP$B-;"0$,<!(B>Y(B=_H%/___TB%P'0B
M2&-4)`1(BP53:B``2(T$T$B+4`A(A=)(B1!TTDB#P`CK[DB+1"0(9$@S!"4H
M````=`7H,.3__TB#Q!A;7<-!5D%505152(G]4TB)\TB#[!!D2(L$)2@```!(
MB40D"#'`,<"`/CU(C70D!`^4P$F#SO]%,>U(`<-,B?%$B.A(B=_RKDB)[TCW
MT4Z-)#'H?O[__TB%P'0V2(G'2(G"3(GQ1(CH\JY)B<U)]]5-`?5-.>P/AZT`
M```QP(H,`X@,`DC_P(3)=?,QP.D4`0``3(LUC&D@`#'`08G%2/_`28-\QO@`
M=?*#/05Z(```08UU`G0C2&/V3(GW2,'F`^BHX?__2(7`2(D%5FD@`'5`@\C_
MZ<T```!(8_;'!<]Y(``!````2(T\]0````#H^N'__TB%P'3926/53(GV2(G'
M2,'B`^CKX?__2(D%%&D@`$B+!0UI(`!)8]5(QT30"`````!$B6PD!$B)Z(H0
MA-)T"H#Z/70%2/_`Z_!(8TPD!$B+%=UH(`!(*>A(F$F-?`0"3(TLRNB2X?__
M2(7`28E%``^$:?___TAC5"0$2(L%L6@@`$B+!-!(_\6*5?^$TH@0=`J`^CUT
M!4C_P.OJQ@`],=**#!.(3!`!2/_"A,EU\NGE_O__2(M<)`AD2#,<)2@```!T
M!>ARXO__2(/$$%M=05Q!74%>PT%6055!5%532('LH````&1(BP0E*````$B)
MA"28````,<!(A?\/A.\```"`/P!(B?T/A.,```#H4>#__TB%P$F)Q$R-;"0(
M#X3-````3(GGZ*#@__](A<`/A*P```!(C5@32(TU[14``$B)W^A\X/__A<!T
MV$B--=D5``!(B=_H:>#__X7`=,5(@\[_,<!(B>](B?'RKDB)WTB)RDB)\?*N
M2/?22(G(2/?0C3P02&/_Z'#@__](C36<%0``28G&2(G'2(G92(GJ,<#H=N'_
M_TR)]TR)[NA+X?___\!,B?=T%XM$)"`E`/```#T`0```=0?H"O___^L%Z"#@
M__],B??H&.'__^E#____3(GGZ#O@__](B>_HZ^#__TB+A"28````9$@S!"4H
M````=`7H,^'__TB!Q*````!;74%<05U!7L-32(G[BST99R``Z.S@__](C;#X
M`0``2(G?Z.7?__^%P'0$,<#K4XL]]V8@`.C*X/__BX`0`@``)0#P```]`$``
M`'47O@(```!(B=_H(]___X7`#Y3`#[;`ZQ^+/<-F(`#HEN#__XN`$`(``"4`
M\```/0"@``!UJ^O*6\-(@^P(BSV>9B``Z''@__](BQ5:92``2(G'2(T-`%4`
M`%A(C35Y%```Z4/@__](@^P(BSUQ9B``Z$3@__](B<?HO/___XL]7F8@`.@Q
MX/__2(G'3(T%&A<``$B-%6\0``!82(TU510``$4QR4R)P>F5WO__05154TB!
M[!`@``!(C6PD!F1(BP0E*````$B)A"0((```,<#HC=[__TR-!3`4``!(C14M
M%```B<&^`1```#'`2(GOZ$;>__^#^/]U!S')Z8$```!(8]!(@?H`$```=@(/
M"X7`>.=(C9PD!Q```+H`$```2(GO2(G>Z/C>__^%P$F)Q'C(C7@!2&/_Z&;>
M__](A<!(B<%TM4@YV$EC[',)2(T$*$@YPW*W2#G9=@E(C00K2#G!<JE!@?P!
M$```?Z!(B<](B>I(B=[H4-___TB)P<8$*`!(B[0D""```&1(,S0E*````$B)
MR'0%Z$;?__](@<00(```6UU!7,/I`/___T%6055!5%5(B?U32(T]71,``$B)
M\TB![!`0``!D2(L$)2@```!(B80D"!```#'`Z#+Z__^^+P```$B)[TF)Q>@)
MWO__2(7`=!9(C3TH$P``2(GN,<#HLOK__^DV`0``,<!(B>](@\G_\JY(C344
M$P``2(G?3(UD)`A(]]%$C7'_Z(#>__](B<-(A=MTO(`[`$B-!8\2``!(#T38
M387M=!-(B=Y,B>_H$MW__X7`#X3,````,<!(@\G_2(G?\JY(]]&-0?](8]"`
M?!/_+W4+_\A(8]#&!!,`Z^M"C40P`3W_#P``#X]@____3(T%EQ(``$B-%:@3
M```QP$F)Z4B)V;X`$```3(GGZ('<____P#T`$```=@(/"XL]&&0@`.CKW?__
M2(VP^`$``$R)Y^C$W?__A<!U2HL]^F,@`.C-W?__BX`0`@``)0#P```]`(``
M`'4MO@$```!,B>?H)MS__X7`=1Q(C3T.$@``3(GFZ)KY__],B>?HJ]S__TB)
MQ>L62(TU_Q$``#'_Z'C=__](B</I\_[__TB+E"0($```9$@S%"4H````2(GH
M=`7HA=W__TB!Q!`0``!;74%<05U!7L-(C5<!2(GXBDK_A,ET#(#Y+T@/1,)(
M_\+K[<-(A?]T2T2*!TB)_D6$P'1`,<!(@\G_\JY(]]%(C50._D@YUG,9@#HO
M=0U(_\KK\4C_RD@YUG,'@#HO=?/K(T@YUG4>08#X+TB-/5X1``!U!TB-/?00
M``#I[MO__X`Z+W4(2/_*2#G6<O-(*?)(C4("2#T`$```=R=(_\)(@?H`$```
M=@(/"TB-/55C(`!(@^P(Z`S<__](C05%8R``6L,QP,-32(TU`%$``+DB````
M2(/L,&1(BP0E*````$B)1"0H,<!(C7PD!DB-7"0&\Z1(C3W8$```Z.CW__](
MC3W5$```,<#HVO?__TB-/<\0```QP.C,]___2(T]RA```#'`Z+[W__](C3W#
M$```,<#HL/?__TB-/<40```QP.BB]___2(T];!```#'`Z)3W__](C3VU$```
M,<#HAO?__TB-/;$0```QP.AX]___2(T]K1```#'`Z&KW__](C3T]$```,<#H
M7/?__TB-/9L0```QP.A.]___2(T]EA```#'`Z$#W__](C3V3$```,<#H^O;_
M_TB%P'012(T]6!```$B)QC'`Z(KW__](C3V`$```,<#HUO;__TB%P'012(T]
M?Q```$B)QC'`Z&;W__](C3UY$```,<#HLO;__TB%P$B)QDB-/:X/``!U'4B-
M/6P0```QP.B5]O__2(7`=`Y(C3WI#P``2(G&,<#K)$B->Q%(C358$```N@H`
M``#H#-K__X7`=1!(C7,;2(T]O@\``.C_]O__2(TU/A```$B-/8\/```QP.CJ
M]O__2(M$)"AD2#,$)2@```!T!>C^VO__2(/$,%O#@SW)8"``_W4X2(T]>0\`
M`$B#[`@QP.@.]O__,=)(A<!T#HH`A,`/E<(\,`^5P"'"#[;2B1678"``BP61
M8"``6L.+!8E@(`##2(/L".BOVO__B<?HR-G__S'22(7`=`-(BQ!(B=!:PT%7
M059(C37N7R``055!5+D.````55-(B?U)@\W_2(/L2$B)YTF)Y/.E9$B+!"4H
M````2(E$)#@QP$F+'"1(A=L/A(,````QP$B)W^AR]?__2(7`28G&2(GN=%N`
M.`!T5DB)Q^@IV?__2(7`=5-(B>],B>GRKDR)]TB)RDR)Z?*N2/?22(G(2/?0
M2(T\`NB_V/__2(TU8@\``$B-#4$.``!)B<=(B<=-B?!(B>HQP.B^V?__3(G^
M2(G?,<#HJ/7__TF#Q`CI</___TB+1"0X9$@S!"4H````=`7HL]G__TB#Q$A;
M74%<05U!7D%?PT%7059(C35!7R``055!5$F)_553N0P```!(@>Q(@0``9$B+
M!"4H````2(F$)#B!```QP$B-!;4.``!(C7PD2$C'1"0H`````/.E2(E$)!A(
MC04_#0``2(T]@0T``$C'1"1``````$B)1"0@2(T%@@X``$B)1"0P2(T%>PX`
M`$B)1"0X,<#H2_3__TB%P'0@@#@`2(G#=!A(B<?H=/[__TB)W^CMU___2(G%
MZ>\(```QP$B-;"0PZ#G^__](A<!(B<-U.4B+?0!(A?]T*3'`,=OH`/3__TB%
MP'00@#@`=`M(B<?HK=?__TB)PTB#Q0A(A=MTT.L'2(T=[`T``#'`2(G?2(/)
M__*N3(TU]`T``$CWT4B-?`G_Z$G7__](B<5)B<2`.P!T&0^V$TR)YTR)]C'`
M2/_#28/$`NA'V/__Z^),C60D2$F+'"1(A=MT+DB)WS'`Z'[S__](A<!(B<-T
M(X`X`'0>2(G'Z!7W__^%P'022(G?Z!S7__](B<-,C70D&.LP28/$".N\38LF
M387D="=!@#PD`'0@3(GGZ.+V__^%P'0+3(GGZ.G6__](B<-)@\8(2(7;=-%(
M@\[_,<!(B=](B?'RKDB)[TCWT4B)RDB)\?*N2(G(2/?01(V\$`($``!-8_],
MB?_H>-;__TR-!10-``!(C0W\"P``2(TU"PT``$B)QTF)Q$F)Z4B)VC'`Z'#7
M__^^P`$``$R)Y^@SU____\!U,^@BU___@S@1="GH&-?__TF+50!$BP!(C373
M#```2(L]0UT@`$R)X3'`Z,'6___I1`<``(L]1ET@`.@9U___2(VP^`$``$R)
MY^@2UO__A<!!B<8/A0,'``"+/2%=(`#H]-;__XN`$`(``"4`\```/0!````/
MA>(&``"+/0!=(`#HT];__XN8%`(``.CXUO__.<,/A<0&``"+/>)<(`#HM=;_
M_XN`$`(``"7_`0``/<`!```/A:,&``!,B?_H?]7__TB-/=H+``!(B<4QP.C?
M\?__2(7`=!Q(B<?HD=7__TF+?0!(B<;H8/?__TB%P$F)QW4$38M]`#'`2(/)
M_TR)__*N2/?12(U9_X/[`WYC2&/#2(TU%`P``$F-?`?\Z.;4__^%P'5+@_L$
M=`Z#ZP1(8]M!@'P?_R]U.$F+70A(A=MT+S'`2(/)_TB)W_*N2/?12(U!_TB#
M^`-V%TB-?`O[2(TURPL``.B=U/__A<!,#T3[,<#H$/O__X7`#X4F!0``,?9,
MB?_H[M3__X7`08G'#X01!0``3(VL)#@!``"Z`@```$C'QN[___^)Q^A(U/__
MN@8```!,B>Y$B?_H4-7__X"\)#@!````=66`O"0Y`0``0W5;@+PD.@$``$%U
M48"\)#L!``!#=4>`O"0\`0``2'4]@+PD/0$``$5U,[H"````2,?&QO___T2)
M_^CHT___NBD```!,B>Y$B?_H\-3__TR-#20,``!-B>CI5P0``#'2,?9$B?_H
MO=/__[B)J\WO2(U<)'A(QT0D>`$C16=(B80D@````+C^W+J82,>$))````!V
M5#(02(F$)(@```"X\.'2PTC'A"2@`````````$B)A"28````2,>$)*@`````
M````QX0D\`````````"Z`(```$R)[D2)_^AAU/__A<!)B<!!B<8/CGX!``!(
MBXPDH````$ECP(T4P4@YT78(2/^$)*@```!(P>@=2`&$)*@```!(8X0D\```
M`$B)E"2@````A<`/A)<```!!OD````!(C7P#.$$IQD4Y\$4/3O!,.>])8\YS
M"4B-!`]).<5R#TPY[W8,28U$#0!(.<=S`@\+2('Y`(```$R)1"0(=_!(B<I,
MB>Y(B0PDZ!C4__^+A"3P````2(L,)$R+1"0(1`'P@_A`B80D\`````^%+/__
M_TF-=`T`1(G`2(G?1"GP2(DT)$&)QNA(U___2(LT).L#3(GN2(U+.$&#_C]^
M34@YSG8)2(U#>$@YQG*#2#G.3(U&0',)3#G!#X)Q____2(G/ND````!(B4PD
M"$R)!"1!@^Y`Z([3__](B=_H\];__TB+3"0(2(LT).NM2(U#.$ECUD@YQG8,
M2`'02#G&#X(L____2(U#.$@YQG,-2(T,%D@YR`^"%O___TB#^D@/APS___](
MC7LXZ#K3__]$B;0D\````.ED_O__1(G_Z+W2__],B[0DH````$R+K"2H````
M3(GP2,'H`X/@/XU(`4B8QH0$L````("#^3A(8_E^+$R->SBZ0````#'V*<I(
M8]),`?_HGM'__TB)W^A#UO__NC@````Q]DR)_^L1NC@```!(C7P[.#'V*<I(
M8]+H=-'__TR)Z$B)WT2(K"3K````2,'H&$2(M"3O````,=N(A"3H````3(GH
M2,'H$(B$).D```!,B>A,C:PD^P```$C!Z`B(A"3J````3(GP2,'H&(B$).P`
M``!,B?!(P>@0B(0D[0```$R)\$C!Z`B(A"3N````Z*O5__](BT0D>$R-A"0/
M`0``2(G"B(0D_@```$C!ZAB(E"3[````2(G"2,'J$(B4)/P```!(B<)(BX0D
M@````$C!Z@B(E"3]````2(G"B(0D`@$``$C!ZAB(E"3_````2(G"2,'J$(B4
M)``!``!(B<)(BX0DB````$C!Z@B(E"0!`0``2(G"B(0D!@$``$C!ZAB(E"0#
M`0``2(G"2,'J$(B4)`0!``!(B<)(BX0DD````$C!Z@B(E"0%`0``2(G"B(0D
M"@$``$C!ZAB(E"0'`0``2(G"2,'J$(B4)`@!``!(B<)(BX0DF````$C!Z@B(
ME"0)`0``2(G"B(0D#@$``$C!ZAB(E"0+`0``2(G"2,'J$(B4)`P!``!(B<)(
MP>H(B)0D#0$``$(/MA0K2(T\&TB--8(&```QP$C_PTR)!"1,`<?H\]#__TB#
M^Q1,BP0D==5,C0W-!P``QH0D-P$```!(C0U%!0``2(TUH@8``$R)XDB)[S'`
MZ+_0___IDP```$B--?`%``!(C3U=!0``,<!(C1V.!P``Z)7L___H.<___TR-
M#7T'``!(C0W]!```2(TU:08``$&)P$R)XDB)[S'`Z'30__^^P`$``$B)[^@W
MT/___\!U/.@FT/__@S@1=3+H],[__TB#[`A!_\9(C0VX!```4TB--3$&``!!
MB<!,B>)%B?%(B>\QP.@KT/__6%KKLTR)Y^CWS___2(T]<@0``$B)[C'`Z`7L
M__](B>_HE?7__^L>28M5`$B+/0%6(`!(C37V!0``3(GA,<#H>,___S'M2(NT
M)#B!``!D2#,T)2@```!(B>AT!>CKS___2('$2($``%M=05Q!74%>05_#055!
M5%532(/L"(L]R54@`.B<S___BSV^52``2(G#Z([/__^*@+````!(C3T>!```
MB(.Q````,<#HS>K__TB%P'0+@#@Q=0:`>`$`=`<QP.C-\O__BSU_52``Z%+/
M__](C36V!0``N0L```"Z`0```$B)Q^AQSO__2(7`=36+/595(`#H*<___TB-
M-9(%``"Y`P```+H!````2(G'Z$C.__](A<!(B<,/A<H```#I#`$``$B+0!`Q
MVTR+8"B-:P$[+:QE(`!]((L]#%4@`.C?SO__,<E(8]-,B>9(B<?HE\W__TB%
MP'43BP6$92``_\@YPW6*NP$```#K5TR+*$&+10PE``0@`#T`!```=09)BT40
MZQV+/<!4(`#HD\[__[D"````,=),B>Y(B<?HH<[__TB+#3)E(`!(8]5(B<9(
MBSS1Z!O-__^%P'6=B>OI:____SL=&F4@``^-(/___XL]=E0@`/_#Z$?.__],
MB>9(B<?HE,S__^O:2(M`$(L]6%0@`$B+*.@HSO__2(T5DP0``$B)QTB)[NA>
MS?__2(M#$$B+&/9##D!T%HL]*U0@`.C^S?__2(G>2(G'Z,O,__^+/154(`#H
MZ,W__TB--<H"``"Y`P```+H!````2(G'Z`?-__](A<!(B<4/A(<```!(C3TG
M`@``,<#H#NG__TB%P$B)PW0:2(M%$(L]RU,@`$B+*.B;S?__2(G:2(GNZT_H
M@>W__TB%P$B)PXL]JE,@`$B+11!T($B+*.ATS?__2(G:2(G'2(GNZ*[,__](
MB=_H/LW__^L@2(L5#60@`$B+&$B+*NA*S?__2(G>2(GJ2(G'Z(3,__^+/5Y3
M(`#H,<W__TB--:$#``"Z`0```$B)Q^B-R___BST_4R``2(G#Z`_-__](C164
M`P``2(G>2(G'Z$7,__^+/1]3(`#H\LS__TB-/4T!``#&@+$`````,<#H-NC_
M_TB%P$B)!9MC(`!U)$B+/8)C(`#H2?/__TB%P$B)!8-C(`!U#$B-/40#``#H
M/<O__TB+/6YC(`"^P`$``.ATS/__C5`!@_H!=B:#^!%T(8G!2(L%/F,@`$B+
M%4=C(`!(C3TK`P``2(LP,<#H_LK__UA;74%<05W#55-(B?M(@^P(Z";O__](
MB<?H`^___TB)Q3'`Z';Q__^%P'0I2(7;="2`.P!T'TB--;P!``!(B>_H4<O_
M_T@YQ74+6DB)WUM=Z=SI__]86UW#54B)Y5-(C1VQ32``2(/L"$B#ZPA(BP-(
M@_C_=`3_T.OO6%M=PU#HH<[__UC#+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?
M05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%2
M7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?
M0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(
M`%-94U1%30`O=&UP`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*`%1%35!$25(`5$U0`$%21U8`&`!P97)L`%!!
M4CHZ4&%C:V5R.CI615)324].`#$N,#,U`%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC
M;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^
M9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A
M;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%2
M7T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D
M14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U
M="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O
M=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S
M96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@
M;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O
M=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE
M;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*
M;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@
M=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O
M<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M
M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N
M86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT
M("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY
M("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z
M("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P
M,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H
M)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B
M/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S
M970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R
M96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS
M:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>
M+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT
M(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI
M.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI
M.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#([
M"G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS
M92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O
M9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY
M("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F
M+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,````!&P,[P```
M`!<```"4B?__W````(R+__\$!0``T8[__P0!```DIO__5`$``*VF__^<`0``
MY:;__[0!``!3I___W`$``!>I__\D`@``6:K__VP"``#4JO__C`(```&K__^D
M`@``1ZO__[P"``!"K/__]`(``$>L__\,`P``!Z[__U0#```BKO__;`,``,2N
M__^$`P``A+#__ZP#``#,L/__Q`,``.NP___<`P``V+'__RP$``"CN___C`0`
M`.Z^___,!```%``````````!>E(``7@0`1L,!PB0`0``)````!P```"PB/__
M$``````.$$8.&$H/"W<(@``_&CLJ,R0B`````$P```!$````Q8W__U,7````
M0@X0CP)"#AB.`T8.((T$0@XHC`5##C"&!D$..(,'1P[0!0,Q%PXX00XP00XH
M0@X@0@X80@X00@X(````````1````)0```#(I/__B0````!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P=&#D`":PXX1`XP00XH0@X@0@X80@X00@X(
M%````-P````)I?__.`````!$#B!S#@@`)````/0````II?__;@````!!#A"&
M`D$.&(,#1PXP`F(.&$$.$$$."$0````<`0``;Z7__\0!````0@X0C@)"#AB-
M`T(.((P$00XHA@5$#C"#!D<.0`.I`0XP00XH00X@0@X80@X00@X(````````
M`$0```!D`0``ZZ;__T(!````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.
MT`$#*@$.,$$.*$$.($(.&$(.$$(."````````!P```"L`0``Y:?__WL`````
M00X0@P(">0X(````````%````,P!``!`J/__+0````!$#A!=#@@`%````.0!
M``!5J/__1@````!$#A!P#@@`-````/P!``"#J/__^P````!"#A",`D$.&(8#
M00X@@P1'#K!``NL.($$.&$$.$$(."``````````4````-`(``$:I__\%````
M``````````!$````3`(``#.I___``0```$(.$(X"0@X8C0-"#B",!$$.*(8%
M1`XP@P91#L`@`YL!#C!!#BA!#B!"#AA"#A!"#@@````````4````E`(``*NJ
M__\;```````````````4````K`(``*ZJ__^B``````*1#A!-#@@D````Q`(`
M`#BK___``0```$$.$(,"4`Y``ZT!#A!!#@@`````````%````.P"``#0K/__
M2`````!4#A!L#@@`%`````0#````K?__'P````!$#A!:#@@`3````!P#```'
MK?__[0````!"#A"/`D(.&(X#20X@C01"#BB,!48.,(8&00XX@P=+#H`!`L$.
M.$$.,$$.*$(.($(.&$(.$$(."`````````!<````;`,``*2M___+"0```$(.
M$(\"0@X8C@-)#B"-!$(.*(P%1`XPA@9!#CB#!TP.@(,"`Q0)#HB#`DL.D(,"
M6PZ(@P)!#H"#`@)E#CA!#C!!#BA"#B!"#AA"#A!"#@@\````S`,```^W__]+
M`P```$(.$(T"0@X8C`-!#B"&!$$.*(,%1`XP`SH##BA!#B!!#AA"#A!"#@@`
M````````-`````P$```:NO__40````!!#A"&`D$.&(,#1PX@>@H.&$0.$$$.
M"$4+00X800X000X(```````D````1`0``("&___6`0```$$.$(,"1`XP`\T!
M#A!##@@`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````__________\``````````/______
M____``````````````````````$``````````0`````````!`````````-P"
M````````#P````````!K`P````````P`````````N!@````````-````````
M`*!.````````]?[_;P`````@`@````````4`````````0`P````````&````
M`````!`#````````"@````````!H!`````````L`````````&``````````5
M`````````````````````P````````#(G2````````<`````````J!``````
M```(`````````!`(````````"0`````````8`````````!@`````````````
M``````#[__]O``````$```@`````^?__;P`````.````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````6)P@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````N!@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@(```````````````````````````````````````X4\`
M``````#73P```````.1/````````VD\```````#?3P```````/%/````````
M`````````````````````)Y/````````ET\```````#O4````````+1/````
M````]U```````````````````/____\`````BE$```````!'0T,Z("A!;'!I
M;F4@-BXR+C$I(#8N,BXQ(#(P,38P.#(R```N<VAS=')T86(`+FEN=&5R<``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N:6YI=``N<&QT
M`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M``````````````````````````````````````````````````L````!````
M`@```````````@`````````"````````&0````````````````````$`````
M```````````````3````]O__;P(`````````(`(````````@`@```````.P`
M`````````P`````````(````````````````````'0````L````"````````
M`!`#````````$`,````````P"0````````0````!````"``````````8````
M`````"4````#`````@````````!`#````````$`,````````:`0`````````
M``````````$````````````````````M````!`````(`````````J!``````
M``"H$````````!`(`````````P`````````(`````````!@`````````-P``
M``$````&`````````+@8````````N!@````````-````````````````````
M`0```````````````````#T````!````!@````````#0&````````-`8````
M````$````````````````````!``````````$`````````!"`````0````8`
M````````X!@```````#@&````````.@!```````````````````(````````
M````````````2P````$````&`````````,@:````````R!H```````#8,P``
M`````````````````0```````````````````%$````!````!@````````"@
M3@```````*!.````````"`````````````````````$`````````````````
M``!7`````0````(`````````J$X```````"H3@```````))`````````````
M```````(````````````````````7P````$````"`````````#R/````````
M/(\```````#$````````````````````!````````````````````&T````!
M`````@``````````D`````````"0````````;`0```````````````````@`
M``````````````````!W`````0````,`````````,)P@```````PG```````
M`!`````````````````````(````````````````````?@````$````#````
M`````$"<(```````0)P````````0````````````````````"```````````
M`````````(4````!`````P````````!0G"```````%"<````````"```````
M``````````````@```````````````````"*````!@````,`````````6)P@
M``````!8G````````'`!````````!``````````(`````````!``````````
M1@````$````#`````````,B=(```````R)T````````X`@``````````````
M````"``````````(`````````),````!`````P``````````H"````````"@
M````````H````````````````````"````````````````````"9````"```
M``,`````````H*`@``````"@H````````,@0```````````````````@````
M````````````````G@````$````P````````````````````H*`````````C
M`````````````````````0`````````!``````````$````#````````````
M`````````````,.@````````IP````````````````````$`````````````
%````````
